from __future__ import absolute_import

__title__ = 'i18next.templatetags.i18next'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = (
    'OverrideLocaleNode', 'overridelocale', 'DisableTranslationsNode',
    'disabletranslations',
)

from django.template.base import (
    Library, Node, TemplateSyntaxError
    )
from django.utils import translation

register = Library()

class OverrideLocaleNode(Node):
    """
    Node for ``overridelocale``.
    """
    def __init__(self, language_code, nodelist):
        self.language_code = language_code
        self.nodelist = nodelist

    def render(self, context):
        language_code = self.language_code.resolve(context)
        with translation.override(language_code):
            return self.nodelist.render(context)


@register.tag
def overridelocale(parser, token):
    """
    Overrides locale for certain code block.

    Example usage::

        {% overridelocale 'en' %}
            <p>
                <a href="/login/">{% trans "Log in" %}</a>
            </p>
        {% endoverridelocale %}
    """
    bits = token.split_contents()

    if not 2 == len(bits):
        raise TemplateSyntaxError("{0} expected at least one variable "
                                  "assignment".format(bits[0]))

    language_code = parser.compile_filter(bits[1])

    nodelist = parser.parse(('endoverridelocale',))
    parser.delete_first_token()
    return OverrideLocaleNode(language_code, nodelist)


class DisableTranslationsNode(Node):
    """
    Node for ``disabletranslations``.
    """
    def __init__(self, nodelist):
        self.nodelist = nodelist

    def render(self, context):
        current_language = translation.get_language()

        translation.deactivate_all()

        rendered = self.nodelist.render(context)

        translation.activate(current_language)

        return rendered

@register.tag
def disabletranslations(parser, token):
    """
    Disables translations for the block.

    Example usage::

        {% disabletranslations %}
            <p>
                <a href="/login/">{% trans "Log in" %}</a>
            </p>
        {% enddisabletranslations %}
    """
    bits = token.split_contents()

    if not 1 == len(bits):
        raise TemplateSyntaxError("{0} does not take any arguments"
                                  "".format(bits[0]))

    nodelist = parser.parse(('enddisabletranslations',))
    parser.delete_first_token()
    return DisableTranslationsNode(nodelist)



__title__ = 'django-i18next'
__version__ = '0.1'
__build__ = 0x000001
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
#__all__ = ('default_app_config',)

default_app_config = 'i18next.apps.Config'



__title__ = 'i18next.test'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'

import unittest

from i18next.testing.test_core import I18NextCoreTest

if __name__ == '__main__':
    unittest.main()



__title__ = 'i18next.testing.helpers'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = ('setup_i18next',)

from django.core.management import call_command

from i18next.testing.base import (
    is_i18next_setup_completed, mark_i18next_setup_as_completed
)

def setup_i18next(collectstatic=False):
    """
    Set up i18next.
    """
    if is_i18next_setup_completed():
        return False

    if collectstatic:
        call_command('collectstatic', verbosity=3, interactive=False)

    mark_i18next_setup_as_completed()



__title__ = 'i18next.testing.test_core'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = ('I18NextCoreTest',)

import unittest

from six import text_type
from bs4 import BeautifulSoup

from django.test import TestCase, Client

from i18next.testing.base import print_info
from i18next.testing.helpers import setup_i18next

class I18NextCoreTest(TestCase):
    """
    Tests of django-i18next core functionality.
    """
    def setUp(self):
        setup_i18next()
        c = Client()

        self.response = c.get('/nl/')
        self.soup = BeautifulSoup(self.response.content)

        self.link_overridelocale_en_text = text_type('Log in')
        self.link_normal_text = text_type('Inloggen')
        self.link_disabletranslations_text = text_type('Log in')

    @print_info
    def test_01_overridelocale_en_while_when_set_to_nl(self):
        """
        Test ``overridelocale`` en when visiting Dutch site (locale==nl).
        """
        link_overridelocale_en = self.soup.find(
            'a',
            attrs={'class': 'overridelocale-en'}
            )
        self.assertEqual(link_overridelocale_en.text,
                         self.link_overridelocale_en_text)
        return link_overridelocale_en.text

    @print_info
    def test_02_normal_while_when_set_to_nl(self):
        """
        Test normal when visiting Dutch site (locale==nl).
        """
        link_normal = self.soup.find('a', attrs={'class': 'normal'})
        self.assertEqual(link_normal.text, self.link_normal_text)
        return link_normal.text

    @print_info
    def test_03_disabletranslations_while_when_set_to_nl(self):
        """
        Test ``disabletranslations`` when visiting Dutch site (locale==nl).
        """
        link_disabletranslations = self.soup.find(
            'a',
            attrs={'class': 'disabletranslations'}
            )
        self.assertEqual(link_disabletranslations.text,
                         self.link_disabletranslations_text)
        return link_disabletranslations.text


if __name__ == '__main__':
    unittest.main()



from __future__ import print_function

__title__ = 'i18next.testing.base'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = (
    'PRINT_INFO', 'TRACK_TIME', 'print_info', 'i18next_setup', 'skip',
    'is_i18next_setup_completed', 'mark_i18next_setup_as_completed',
)

PRINT_INFO = True
TRACK_TIME = False

def print_info(func):
    """
    Prints some useful info.
    """
    if not PRINT_INFO:
        return func

    def inner(self, *args, **kwargs):
        if TRACK_TIME:
            import simple_timer
            timer = simple_timer.Timer() # Start timer

        result = func(self, *args, **kwargs)

        if TRACK_TIME:
            timer.stop() # Stop timer

        print('\n{0}'.format(func.__name__))
        print('============================')
        if func.__doc__:
            print('""" {0} """'.format(func.__doc__.strip()))
        print('----------------------------')
        if result is not None:
            print(result)
        if TRACK_TIME:
            print('done in {0} seconds'.format(timer.duration))
        print('\n')

        return result
    return inner

SKIP = False

def skip(func):
    """
    Simply skips the test.
    """
    def inner(self, *args, **kwargs):
        if SKIP:
            return
        return func(self, *args, **kwargs)
    return inner

class I18NextSetup(object):
    """
    Basic setup class in order to avoid the i18next test data
    to be initialised multiple times.
    """
    def __init__(self):
        self.is_done = False

i18next_setup = I18NextSetup()

def is_i18next_setup_completed():
    return i18next_setup.is_done == True

def mark_i18next_setup_as_completed():
    i18next_setup.is_done = True



#__title__ = 'i18next.testing'
#__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
#__copyright__ = '2015 Artur Barseghyan'
#__license__ = 'GPL 2.0/LGPL 2.1'
#
#import unittest
#
#from i18next.testing.test_core import *
#
##if __name__ == '__main__':
##    unittest.main()



import sys
import os
from setuptools import setup, find_packages

try:
    readme = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()
    readme = readme.replace('.. code-block:: none', '.. code-block::')
except:
    readme = ''

#template_dirs = [
#    "src/i18next/templates/i18next", # Core templates
#]
#static_dirs = [
#    "src/i18next/static", # Core static
#]
#locale_dirs = [
#    "src/i18next/locale/nl",
#    "src/i18next/locale/ru",
#    "src/i18next/locale/de",
#]
#
#templates = []
#static_files = []
#locale_files = []
#
#for template_dir in template_dirs:
#    templates += [os.path.join(template_dir, f) for f in os.listdir(template_dir)]
#
#for static_dir in static_dirs:
#    static_files += [os.path.join(static_dir, f) for f in os.listdir(static_dir)]
#
#for locale_dir in locale_dirs:
#    locale_files += [os.path.join(locale_dir, f) for f in os.listdir(locale_dir)]

version = '0.1'

install_requires = [
    'ordereddict>=1.1',
    'six>=1.4.1',
    'Unidecode>=0.04.1',
    'django-nine>=0.1.1',
]

tests_require = [
    'simple_timer>=0.2',
    'selenium',
    'beautifulsoup4',
]

try:
    PY2 = sys.version_info[0] == 2
    LTE_PY26 = PY2 and (7 > sys.version_info[1])
    PY3 = sys.version_info[0] == 3
    #if PY3:
    #    install_requires.append('simplejson>=3.0.0') # When using Python 3
    #else:
    #    install_requires.append('simplejson>=2.1.0') # When using Python 2.*
    #
    #if LTE_PY26:
    #    install_requires.append('ordereddict==1.1')
except:
    pass

setup(
    name = 'django-i18next',
    version = version,
    description = ("Additions to Django's i18n module."),
    long_description = "{0}".format(readme),
    classifiers = [
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Environment :: Web Environment",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "License :: OSI Approved :: GNU Lesser General Public License v2 or "
        "later (LGPLv2+)",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha",
    ],
    keywords = "django, i18n, internationalisation",
    author = 'Artur Barseghyan',
    author_email = 'artur.barseghyan@gmail.com',
    url = 'https://github.com/barseghyanartur/django-i18next/',
    package_dir = {'': 'src'},
    packages = find_packages(where='./src'),
    license = 'GPL 2.0/LGPL 2.1',
    install_requires = install_requires,
    tests_require = tests_require,
    #package_data = {
    #    'i18next': templates + static_files + locale_files
    #},
    include_package_data = True,
)



__title__ = 'i18next.defaults'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = ('DEBUG',)

DEBUG = False



"""
- `DEBUG`
"""
__title__ = 'i18next.settings'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = ('DEBUG',)

from i18next.conf import get_setting

DEBUG = get_setting('DEBUG')
